deploy-actions
==============

|Build Status| |Docs Status| |License: MIT|

CI/CD for Python apps.

Deployments:

- Docs for GitHub Pages
- Docker build and publish on DockerHub
- PyPI test server
- PyPI

Required secrets:

- DOCS_TOKEN
- PYPI_TEST_USERNAME
- PYPI_TEST_PASSWORD
- PYPI_USERNAME
- PYPI_PASSWORD
- DOCKERHUB_USERNAME
- DOCKERHUB_TOKEN

.. |Build Status| image:: https://github.com/desty2k/deploy-actions/workflows/build/badge.svg
   :target: https://github.com/desty2k/deploy-actions/actions?workflow=build
.. |Docs Status| image:: https://github.com/desty2k/deploy-actions/workflows/docs/badge.svg
   :target: https://desty2k.github.io/deploy-actions/
.. |License: MIT| image:: https://img.shields.io/dub/l/vibe-d.svg?color=lightgrey
   :target: https://opensource.org/licenses/MIT
